@@ -13,6 +13,7 @@
 
 #include "GpuDevice.h"
 #include "LinuxBackend.h"
+#include "FreeBSDBackend.h"
 #include "AllGpus.h"
 
 class GpuPlugin::Private
@@ -34,6 +35,10 @@ GpuPlugin::GpuPlugin(QObject *parent, const QVariantList &args)
     d->backend = std::make_unique<LinuxBackend>();
 #endif
 
+#ifdef Q_OS_FREEBSD
+    d->backend = std::make_unique<FreeBSDBackend>();
+#endif
+
     if (d->backend) {
         connect(d->backend.get(), &GpuBackend::deviceAdded, this, [this](GpuDevice* device) {
             d->container->addObject(device);
